BoolIterableExtensions extension

Saropa extensions for Lists of bools

on

Properties

anyFalse → bool

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Checks if any element in the iterable is false.
no setter
anyTrue → bool

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Checks if any element in the iterable is true.
no setter
countFalse → int

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Counts the number of false values in the iterable.
no setter
countTrue → int

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Counts the number of true values in the iterable.
no setter
reverse → List<bool>

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Reverses the boolean values in the list.
no setter

Methods

leastOccurrences() → Occurrence<bool>?

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Finds the least common value in the list.
mostOccurrences() → Occurrence<bool>?

Available on Iterable<bool>, provided by the BoolIterableExtensions extension

Finds the most common value in the list.