set method
void
set(
- K key,
- V value
Stores value under key with a fresh expiry ttl from now.
Implementation
void set(K key, V value) {
_map[key] = (value, DateTime.now().add(_ttl));
}
Stores value under key with a fresh expiry ttl from now.
void set(K key, V value) {
_map[key] = (value, DateTime.now().add(_ttl));
}