invalidate method
void
invalidate(
- K key
Drops the in-memory entry for key without touching the backing store.
Audited: 2026-06-12 11:26 EDT
Implementation
void invalidate(K key) => _cache.remove(key);
Drops the in-memory entry for key without touching the backing store.
Audited: 2026-06-12 11:26 EDT
void invalidate(K key) => _cache.remove(key);