HyperLogLogUtils constructor

HyperLogLogUtils({
  1. int precision = 12,
})

Creates an empty sketch with 2^precision registers.

precision must be in [4, 16]; higher precision means more registers, more memory, and a tighter estimate. Out-of-range values throw because a silent clamp would hide a sizing mistake. Audited: 2026-06-12 11:26 EDT

Implementation

HyperLogLogUtils({this.precision = 12})
  : _registers = List<int>.filled(_validatedRegisterCount(precision), 0);