IntervalSchedulingUtils class

Interval with start and end (inclusive or exclusive per usage).

Constructors

IntervalSchedulingUtils(num start, num end)
Creates an interval spanning start to end.
const

Properties

end num
End of the interval.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start num
Start of the interval.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited