isNotEmpty property
bool
get
isNotEmpty
True when the buffer has at least one element.
Implementation
bool get isNotEmpty => _len > 0;
True when the buffer has at least one element.
bool get isNotEmpty => _len > 0;