WindowAggregate enum

Aggregation kind for a sliding window.

Inheritance
Available extensions

Values

min → const WindowAggregate

Smallest value in each window.

max → const WindowAggregate

Largest value in each window.

sum → const WindowAggregate

Sum of all values in each window.

avg → const WindowAggregate

Arithmetic mean of the values in each window.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WindowAggregate>
A constant List of the values in this enum, in order of their declaration.