add method
Feeds value into the estimator for inclusion in the quantile estimate.
Implementation
void add(num value) {
_buffer.add(value.toDouble());
if (_buffer.length > _maxSize) _buffer.sort();
}
Feeds value into the estimator for inclusion in the quantile estimate.
void add(num value) {
_buffer.add(value.toDouble());
if (_buffer.length > _maxSize) _buffer.sort();
}