lastDayOffsetInWeek constant
int
const lastDayOffsetInWeek
Days from start of week to end of week (0-based index of last weekday).
Implementation
static const int lastDayOffsetInWeek = 6;
Days from start of week to end of week (0-based index of last weekday).
static const int lastDayOffsetInWeek = 6;