Utility class for weekday name operations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDayLongName(
int? dayOfWeek) → String? -
Returns the full name of the given
dayOfWeek(1=Monday, 7=Sunday), ornullifdayOfWeekisnullor invalid. -
getDayShortName(
int? dayOfWeek) → String? -
Returns the abbreviated name of the given
dayOfWeek(1=Monday, 7=Sunday), ornullifdayOfWeekisnullor invalid.
Constants
-
dayLongNames
→ const Map<
int, String> - Full weekday names indexed by DateTime weekday constant (1 = Monday, 7 = Sunday).
-
dayShortNames
→ const Map<
int, String> - Abbreviated weekday names indexed by DateTime weekday constant.