DateTimeBoundsExtensions extension

Start/end of day, week, month, quarter, year; quarter; next weekday; isWeekend.

on

Properties

endOfDay DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

End of day (23:59:59.999999).
no setter
endOfMonth DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

End of month (last day 23:59:59.999999).
no setter
endOfQuarter DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

End of quarter (last day of quarter month 23:59:59.999999).
no setter
endOfYear DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

End of year (Dec 31 23:59:59.999999).
no setter
isWeekend bool

Available on DateTime, provided by the DateTimeBoundsExtensions extension

True if Saturday or Sunday.
no setter
quarter int

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Quarter (1–4).
no setter
startOfDay DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Start of day (00:00:00.000000).
no setter
startOfMonth DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Start of month (first day 00:00:00).
no setter
startOfQuarter DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Start of quarter (first day of quarter month 00:00:00).
no setter
startOfYear DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Start of year (Jan 1 00:00:00). Same as DateTime.yearStart in date_time_extensions.
no setter

Methods

endOfWeek({int firstWeekday = DateTime.monday}) DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

End of week (last day 23:59:59.999999). firstWeekday 1 = Monday.
nextWeekday() DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Next date that is a weekday (skips Saturday/Sunday). If this is already weekday, returns this date at 00:00:00.
sameTimeOn(DateTime other) DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Same calendar date as the receiver with time components from other.
startOfWeek({int firstWeekday = DateTime.monday}) DateTime

Available on DateTime, provided by the DateTimeBoundsExtensions extension

Start of week. firstWeekday 1 = Monday, 7 = Sunday (default Monday).