isAfterNow method
Checks if the date is in the future compared to the current date and time.
Returns true if this date is after now (defaults to current time).
Implementation
@useResult
bool isAfterNow([DateTime? now]) => isAfter(now ?? DateTime.now());