isBeforeNow method

  1. @useResult
bool isBeforeNow([
  1. DateTime? now
])

Checks if the date is in the past compared to the current date and time.

Returns true if this date is before now (defaults to current time). Audited: 2026-06-12 11:26 EDT

Implementation

@useResult
bool isBeforeNow([DateTime? now]) => isBefore(now ?? DateTime.now());