isSameDayMonth method

  1. @useResult
bool isSameDayMonth(
  1. DateTime other
)

Checks if the current DateTime has the same day and month as another DateTime.

Returns true when month and day match, ignoring year.

Implementation

@useResult
bool isSameDayMonth(DateTime other) => month == other.month && day == other.day;