isLeapYear method

  1. @useResult
bool isLeapYear()

Checks if the current year is a leap year using DateTimeUtils.isLeapYear.

Returns: bool: True if the year is a leap year, false otherwise. Audited: 2026-06-12 11:26 EDT

Implementation

@useResult
bool isLeapYear() => DateTimeUtils.isLeapYear(year: year);