mostRecentSunday property
DateTime
get
mostRecentSunday
Returns the most recent Sunday before or on this date.
Implementation
DateTime get mostRecentSunday => mostRecentWeekday(DateTime.sunday);
Returns the most recent Sunday before or on this date.
DateTime get mostRecentSunday => mostRecentWeekday(DateTime.sunday);