RecurrenceFrequency enum

How often a recurrence repeats; the unit the RecurrenceSpec.interval multiplies.

Inheritance
Available extensions

Values

daily → const RecurrenceFrequency

Repeats every N days.

weekly → const RecurrenceFrequency

Repeats every N weeks, optionally on a named weekday.

monthly → const RecurrenceFrequency

Repeats every N months, on a month-day or an nth weekday-of-month.

yearly → const RecurrenceFrequency

Repeats every N years, optionally on a fixed month + day.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RecurrenceFrequency>
A constant List of the values in this enum, in order of their declaration.