OpenWindow class
A single open period within a day, expressed as minutes from midnight:
[startMinute, endMinute). 09:00–17:00 is OpenWindow(540, 1020).
Constructors
- OpenWindow(int startMinute, int endMinute)
-
Creates a window from
startMinutetoendMinute(minutes past midnight). Requires0 <= startMinute < endMinute <= 1440. Audited: 2026-06-12 11:26 EDTconst
Properties
- endMinute → int
-
Exclusive end, minutes past midnight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startMinute → int
-
Inclusive start, minutes past midnight.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited