TimeEmojiUtils class
Utility class for handling time-related emojis, specifically for day/night representation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getEmojiDayOrNight(
int? tzHour) → String? - Returns sunEmoji if the given hour is during daytime (7am inclusive to 6pm exclusive), otherwise returns moonEmoji.