TimeboxException class

Thrown when timebox exceeds the allowed duration and no onTimeout was provided.

Implemented types

Constructors

TimeboxException(String message)
Creates the exception with a message describing the timeout.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Description of the timeout.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited