TimeboxException constructor
TimeboxException(
- String message
Creates the exception with a message describing the timeout.
Implementation
TimeboxException(String message) : _message = message;
Creates the exception with a message describing the timeout.
TimeboxException(String message) : _message = message;