EnumIterableExtensions<T extends Enum> extension
- on
-
- Iterable<
T>
- Iterable<
Methods
-
byNameTry(
String? name, {bool isCaseSensitive = true}) → T? -
Available on Iterable<
Finds and returns the first enum value in this list whoseT> , provided by the EnumIterableExtensions extensionnameproperty matches the givenname, ornullif no such value is found. -
mostOccurrences(
) → MapEntry< Enum, int> ? -
Available on Iterable<
Returns a MapEntry with the most common value and its frequency, orT> , provided by the EnumIterableExtensions extensionnullif the iterable is empty. -
sortedEnumValues(
) → List< T> -
Available on Iterable<
Returns a list of enum values sorted alphabetically by name.T> , provided by the EnumIterableExtensions extension