GestureUtils class abstract final

This is a utility class that contains static methods related to gesture processing.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getSwipeSpeed(double speed) SwipeSpeed
Method to get the swipe speed based on the thresholds defined in _swipeSpeedThresholds.

Constants

swipeMagnitudeThresholds → const Map<SwipeMagnitude, double>
Map for swipe magnitude thresholds.