SwipePropsExt extension

The DragEndDetailsProperties extension adds additional properties to DragEndDetails instances, allowing you to easily determine the direction and speed of a swipe gesture.

on

Properties

swipe → SwipeProperties

Available on DragEndDetails, provided by the SwipePropsExt extension

Method to get a Swipe record for the swipe gesture.
no setter
swipeAngle → SwipeAngle

Available on DragEndDetails, provided by the SwipePropsExt extension

Method to get the swipe angle.
no setter
swipeDirection → SwipeDirection

Available on DragEndDetails, provided by the SwipePropsExt extension

Method to get the swipe direction.
no setter
swipeMagnitude → SwipeMagnitude

Available on DragEndDetails, provided by the SwipePropsExt extension

Method to get the swipe magnitude.
no setter
swipeSpeed → SwipeSpeed

Available on DragEndDetails, provided by the SwipePropsExt extension

Method to get the swipe speed.
no setter