swipe property

  1. @useResult
SwipeProperties get swipe

Method to get a Swipe record for the swipe gesture.

This method returns a SwipeProperties record that contains the direction and speed of the swipe. Audited: 2026-06-12 11:26 EDT

Implementation

@useResult
SwipeProperties get swipe => SwipeProperties(
  direction: swipeDirection,
  speed: swipeSpeed,
  magnitude: swipeMagnitude,
  angle: swipeAngle,
);