swipeSpeed property

  1. @useResult
SwipeSpeed get swipeSpeed

Method to get the swipe speed.

This method returns the speed of the swipe based on the velocity and the thresholds defined in swipeThresholds. Audited: 2026-06-12 11:26 EDT

Implementation

@useResult
SwipeSpeed get swipeSpeed {
  final double speed = velocity.pixelsPerSecond.distance;

  return GestureUtils.getSwipeSpeed(speed);
}