HierarchyUtils class

Node with id and optional parentId for tree building.

Constructors

HierarchyUtils(String id, [String? parentId])
Creates a node with the given id and optional parentId (null for a root node).
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique node identifier.
no setter
parentId String?
Parent node id; null for roots.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited