LineSimplifyUtils class

Point for polyline.

Constructors

LineSimplifyUtils(double x, double y)
Creates a 2D point at coordinates (x, y).
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
X coordinate.
no setter
y double
Y coordinate.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited