IntIterableExtensions extension
NOTE: Dart's type system doesn't consider int to be a subtype of Comparable<int>, even though int does implement Comparable<num>
Methods
-
leastOccurrences(
) → Occurrence< int> ? -
Available on Iterable<
Returns an Occurrence of the least common value and its frequency, orint> , provided by the IntIterableExtensions extensionnullif the iterable is empty. Audited: 2026-06-12 11:26 EDT -
mostOccurrences(
) → Occurrence< int> ? -
Available on Iterable<
Returns an Occurrence of the most common value and its frequency, orint> , provided by the IntIterableExtensions extensionnullif the iterable is empty. Audited: 2026-06-12 11:26 EDT