IntNullableExtensions extension

on

Methods

compareToIntNullable(int? second) int

Available on int?, provided by the IntNullableExtensions extension

Returns a negative value if this is less than second, zero if they are equal, and a positive value if this is greater than second.