ListBinarySearchExtensions<T> extension

Binary search and merge sorted on lists.

on

Methods

binarySearchIndex(T value, [int compare(T a, T b)?]) int

Available on List<T>, provided by the ListBinarySearchExtensions extension

Returns the index of value in this sorted list, or -1 if not found.
binarySearchInsertPoint(T value, [int compare(T a, T b)?]) int

Available on List<T>, provided by the ListBinarySearchExtensions extension

Returns the insertion point for value (index where it would be inserted to preserve order).