getOrNull method
Element at index, or null if out of range.
Implementation
T? getOrNull(int index) => index >= 0 && index < length ? this[index] : null;
Element at index, or null if out of range.
T? getOrNull(int index) => index >= 0 && index < length ? this[index] : null;