ListOfListExtension<T> extension

on

Properties

totalLength int

Available on List<List<T>>, provided by the ListOfListExtension extension

sum the total number of items
no setter
totalUniqueLength int

Available on List<List<T>>, provided by the ListOfListExtension extension

Getting the length of toFlattenedList
no setter

Methods

clone() List<List<T>>

Available on List<List<T>>, provided by the ListOfListExtension extension

Returns a new list that is an exact duplicate of this list.
copy(List<List<T>> destination) bool

Available on List<List<T>>, provided by the ListOfListExtension extension

Copies the elements of this list into destination.
getChildListLengths() List<int>?

Available on List<List<T>>, provided by the ListOfListExtension extension

Returns a list containing the lengths of the child lists in parentList.
toFlattenedList({bool ignoreNulls = true}) List<T>?

Available on List<List<T>>, provided by the ListOfListExtension extension

Extension method that returns a flattened list of unique elements of type T.
toMatrixString({String lineBreak = '\n'}) String?

Available on List<List<T>>, provided by the ListOfListExtension extension

Converts a two-dimensional matrix into a string with comma-separated values and line breaks between rows.