list/unique_list_extensions library

Extensions

UniqueIterableExtensions on Iterable<T>
Deduplication helpers for any iterable, preserving encounter order.
UniqueListExtensionsUniqueBy on List<T>
Deduplication helpers that compare elements by an extracted key.

Typedefs

KeyExtractor<T, E> = E Function(T element)
Extracts a key of type E from an element of type T.