KeyExtractor<T, E> typedef
KeyExtractor<T, E> =
E Function(T element)
Extracts a key of type E from an element of type T.
Implementation
typedef KeyExtractor<T, E> = E Function(T element);
Extracts a key of type E from an element of type T.
typedef KeyExtractor<T, E> = E Function(T element);