MapDefaultExtensions<K extends Object, V extends Object> class

Default map: returns a default value for missing keys.

Wraps a Map and implements Map so that operator [] returns defaultValue when the key is absent. Writes and remove write through.

Implemented types
Available extensions

Constructors

MapDefaultExtensions(Map<K, V> _source, V defaultValue)
Creates a default map with the wrapped map and defaultValue. Audited: 2026-06-12 11:26 EDT

Properties

defaultValue → V
Value returned for missing keys.
final
entries → Iterable<MapEntry<K, V>>
The map entries of this Map.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setteroverride
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setteroverride
keys → Iterable<K>
The keys of this Map.
no setteroverride
length → int
The number of key/value pairs in the map.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<V>
The values of this Map.
no setteroverride

Methods

addAll(Map<K, V> other) → void
Adds all key/value pairs of other to this map.
override
addEntries(Iterable<MapEntry<K, V>> entries) → void
Adds all key/value pairs of newEntries to this map.
override
cast<K2, V2>() → Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
override
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) → bool
Whether this map contains the given key.
override
containsValue(Object? value) → bool
Whether this map contains the given value.
override
forEach(void action(K key, V value)) → void
Applies action to each key/value pair of the map.
override
map<K2, V2>(MapEntry<K2, V2> convert(K key, V value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(K key, V ifAbsent()) → V
Look up the value of key, or add a new entry if it isn't there.
override
remove(Object? key) → V?
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(K key, V value)) → void
Removes all entries of this map that satisfy the given test.
override
toString() → String
A string representation of this object.
override
update(K key, V update(V value), {V ifAbsent()?}) → V
Updates the value for the provided key.
override
updateAll(V update(K key, V value)) → void
Updates all values.
override
withDefault(V defaultValue) → MapDefaultExtensions<K, V>

Available on Map<K, V>, provided by the MapWithDefaultExt extension

Returns a MapDefaultExtensions view that returns defaultValue for missing keys. Audited: 2026-06-12 11:26 EDT

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → V?
The value for the given key, or null if key is not in the map.
override
operator []=(K key, V value) → void
Associates the key with the given value.
override