getChildString method

  1. @useResult
String? getChildString(
  1. String childKey
)

Returns the value for childKey as a String, or null if the key is missing or the value is not a String.

Implementation

@useResult
String? getChildString(String childKey) {
  final dynamic value = this[childKey];

  return value is String ? value : null;
}