map/map_nested_extensions
library
Functions
-
getNested(Map<String, dynamic> map, List<String> path, [Object? defaultValue])
→ Object?
-
Get/set nested value by path (list of keys).
Audited: 2026-06-12 11:26 EDT
-
setNested(Map<String, dynamic> map, List<String> path, Object? value)
→ void
-
Sets
value at the nested location addressed by path in map, creating
intermediate maps as needed. Does nothing if path is empty, or stops early
if an existing intermediate value along path is not a map.
Audited: 2026-06-12 11:26 EDT