isMapNullOrEmpty property
Returns true if this map is null or empty.
Implementation
@useResult
bool get isMapNullOrEmpty => this?.isEmpty ?? true;
Returns true if this map is null or empty.
@useResult
bool get isMapNullOrEmpty => this?.isEmpty ?? true;