isNotMapNullOrEmpty property
Returns true if this map is not null and not empty. Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
bool get isNotMapNullOrEmpty => this?.isNotEmpty ?? false;
Returns true if this map is not null and not empty. Audited: 2026-06-12 11:26 EDT
@useResult
bool get isNotMapNullOrEmpty => this?.isNotEmpty ?? false;