MapPickOmitExtensions<K, V> extension
Pick and omit keys from maps.
- on
-
- Map<
K, V>
- Map<
Methods
-
omit(
Iterable< K> keys) → Map<K, V> -
Available on Map<
Returns a new map containing all entries whose keys are not inK, V> , provided by the MapPickOmitExtensions extensionkeys. -
pick(
Iterable< K> keys) → Map<K, V> -
Available on Map<
Returns a new map containing only entries whose keys are inK, V> , provided by the MapPickOmitExtensions extensionkeys.