NumberExtensions extension

Extension methods for num covering sign checks and string length.

on

Properties

isNotZeroOrNegative → bool

Available on num, provided by the NumberExtensions extension

Returns true if the number is not zero and not negative.
no setter
isZeroOrNegative → bool

Available on num, provided by the NumberExtensions extension

Returns true if the number is zero or negative.
no setter

Methods

length() → int

Available on num, provided by the NumberExtensions extension

Returns the number of characters in the string representation of this number.