toIntOrNull method
Converts this nullable num to an int, or returns null if null.
Implementation
@useResult
int? toIntOrNull() => this?.toInt();
Converts this nullable num to an int, or returns null if null.
@useResult
int? toIntOrNull() => this?.toInt();