num/num_lerp_utils library

Functions

inverseLerp(double a, double b, double value) double
Returns where value falls between a and b as a fraction in 0.01.0.
lerp(double a, double b, double t) double
Lerp, inverse lerp, map value from one range to another. Roadmap #130–132.
mapRange(double value, double fromMin, double fromMax, double toMin, double toMax) double
Remaps value from the input range [fromMin, fromMax] to the output range [toMin, toMax].