hasHeader property
bool
get
hasHeader
Whether the first row was treated as a header row.
Implementation
bool get hasHeader => _hasHeader;
Whether the first row was treated as a header row.
bool get hasHeader => _hasHeader;