lineNumber property
1-based line number in the original input (blank lines are counted, so this maps back to what the user sees in their file).
Implementation
final int lineNumber;
1-based line number in the original input (blank lines are counted, so this maps back to what the user sees in their file).
final int lineNumber;