column property
int?
get
column
The 1-based column where the error occurred, or null if unknown.
Implementation
int? get column => _column;
The 1-based column where the error occurred, or null if unknown.
int? get column => _column;