line property
int?
get
line
The 1-based line where the error occurred, or null if unknown.
Implementation
int? get line => _line;
The 1-based line where the error occurred, or null if unknown.
int? get line => _line;