end property
Last byte offset (inclusive), or null for an open-ended range; for a suffix range it is the count of trailing bytes.
Implementation
final int? end;
Last byte offset (inclusive), or null for an open-ended range; for a suffix range it is the count of trailing bytes.
final int? end;