regex/regex_match_utils library

Functions

matchAll(RegExp re, String input) List<RegExpMatch>
Match all (return all matches with groups). Replace with callback. Named group map. Roadmap #190, #191, #193.
namedGroupMap(RegExpMatch match) Map<String, String>
Returns the named capture groups of match as a map of name to value.
replaceAllWithCallback(String input, RegExp pattern, String replace(Match match)) String
Replaces every match of pattern in input with the result of replace.