FunnelUtils class

Step name and count of users who reached it.

Constructors

FunnelUtils(String name, int count)
Creates a funnel step named name reached by count users.
const

Properties

count int
Number of users who reached this step.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
The step's display name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited