message property
String
get
message
Human-readable description of the conflict or error that blocked the patch.
Implementation
String get message => _message;
Human-readable description of the conflict or error that blocked the patch.
String get message => _message;