ApplyPatchSuccess class final

Patch applied successfully; text is the result.

Inheritance

Constructors

ApplyPatchSuccess(String text)
Creates a success result wrapping the patched text.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The fully patched output text.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited