DiffOutputFormat enum
Format for unified diff output.
Values
- plain → const DiffOutputFormat
-
Plain text with +/- prefix (no color).
- ansi → const DiffOutputFormat
-
ANSI escape codes for terminal (green add, red remove).
- html → const DiffOutputFormat
-
HTML spans with classes (add/remove for styling).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DiffOutputFormat> - A constant List of the values in this enum, in order of their declaration.