index property
int
get
index
Position of this match within the original candidates list.
Implementation
int get index => _index;
Position of this match within the original candidates list.
int get index => _index;