string/glob_utils library
Simple glob matching (**/*.dart style).
Tree-shakeable: import only this file if you need glob match.
Classes
- GlobUtils
- Glob-style pattern matching. Supports * (any sequence), ? (one char), ** (any path).
Simple glob matching (**/*.dart style).
Tree-shakeable: import only this file if you need glob match.