SearchQueryParserUtils class abstract final

Simple parser: "a b" = AND, "a OR b", quoted = phrase, -x = exclude.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseSearchQuery(String query) → List<QueryTerm>
Parses query into a list of QueryTerm (words/phrases, AND/OR, minus). Audited: 2026-06-12 11:26 EDT