SensitiveScrubUtils class

A scrubber rule: pattern is replaced by replacement when matched.

Constructors

SensitiveScrubUtils(RegExp pattern, String replacement)
Creates a rule that replaces every match of pattern with replacement.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern RegExp
Regular expression identifying the sensitive substrings to mask.
final
replacement String
Text substituted in place of each pattern match (e.g. "EMAIL").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited