SoundexUtils class abstract final

Soundex encoding: words that sound similar produce the same code.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encode(String s) String
Encodes this string using Soundex (first letter + 3 digits).
soundsLike(String a, String b) bool
Returns true if a and b have the same Soundex code.