endsWithPunctuation method
Returns true if this string ends with punctuation (., ?, or !).
Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
bool endsWithPunctuation() => endsWithAny(const <String>['.', '?', '!']);
Returns true if this string ends with punctuation (., ?, or !).
Audited: 2026-06-12 11:26 EDT
@useResult
bool endsWithPunctuation() => endsWithAny(const <String>['.', '?', '!']);