isLatin method
Returns true if this string contains only Latin alphabet characters
(a-z, A-Z).
Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
bool isLatin() => _latinRegex.hasMatch(this);
Returns true if this string contains only Latin alphabet characters
(a-z, A-Z).
Audited: 2026-06-12 11:26 EDT
@useResult
bool isLatin() => _latinRegex.hasMatch(this);