graphemeLength property
Gets the grapheme length (number of user-perceived characters).
This counts Unicode grapheme clusters rather than code units. For example, an emoji like 👨👩👧 counts as 1 grapheme even though it consists of multiple code points. Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
int get graphemeLength => characters.length;