nonBreakingHyphen constant
String
const nonBreakingHyphen
For not breaking words into newline at hyphen in Text.
Implementation
static const String nonBreakingHyphen = '\u2011';
For not breaking words into newline at hyphen in Text.
static const String nonBreakingHyphen = '\u2011';