normalizeApostrophe method
Returns a new string with apostrophe variants replaced by a standard single quote.
Implementation
@useResult
String normalizeApostrophe() => replaceAll(_apostropheRegex, "'");
Returns a new string with apostrophe variants replaced by a standard single quote.
@useResult
String normalizeApostrophe() => replaceAll(_apostropheRegex, "'");