removeFirstChar method
Returns a new string with the first character removed. Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
String removeFirstChar() => (length < 1) ? '' : substringSafe(1);
Returns a new string with the first character removed. Audited: 2026-06-12 11:26 EDT
@useResult
String removeFirstChar() => (length < 1) ? '' : substringSafe(1);