removeFirstLastChar method
Returns a new string with both the first and last characters removed.
Implementation
@useResult
String removeFirstLastChar() => (length < 2) ? '' : substringSafe(1, length - 1);
Returns a new string with both the first and last characters removed.
@useResult
String removeFirstLastChar() => (length < 2) ? '' : substringSafe(1, length - 1);