removeMatchingWrappingBrackets method
Returns a new string with the outer matching bracket pair removed.
Implementation
@useResult
String removeMatchingWrappingBrackets() =>
isBracketWrapped() ? substringSafe(1, length - 1) : this;
Returns a new string with the outer matching bracket pair removed.
@useResult
String removeMatchingWrappingBrackets() =>
isBracketWrapped() ? substringSafe(1, length - 1) : this;