isNumeric method
Returns true if this string can be parsed as a number.
Audited: 2026-06-12 11:26 EDT
Implementation
@useResult
bool isNumeric() =>
// Attempt to parse as a double and check if the result is not null.
double.tryParse(this) != null;