StringPunctuation extension

Extension on String to provide punctuation removal functionality.

on

Methods

removePunctuation() → String

Available on String, provided by the StringPunctuation extension

Removes punctuation characters from a string, while preserving alphabetic characters (including accented characters and characters from other languages like Chinese, Japanese, and Korean), numbers, and whitespace.

Static Properties

punctuationRegex → RegExp

Available on String, provided by the StringPunctuation extension

Regular expression to remove punctuation while preserving alphabetic characters, numbers, and whitespace.
final