SearchMatchType enum

Search match type for string matching operations.

Inheritance
Available extensions

Values

contains → const SearchMatchType

Match if the string contains the search term.

startsWith → const SearchMatchType

Match if the string starts with the search term.

exact → const SearchMatchType

Match if the string exactly equals the search term.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SearchMatchType>
A constant List of the values in this enum, in order of their declaration.