UrlExtractUtils class

One extracted link with optional label and surrounding snippet.

Constructors

UrlExtractUtils(String url, {String? label, String? snippet})
Creates an extracted link for url, with an optional anchor label and surrounding snippet of context.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
Visible link text/anchor when the URL was part of markup, else null.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snippet String?
Surrounding text giving context around the link, or null if unavailable.
no setter
url String
The extracted URL.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited