snippet property
String?
get
snippet
Surrounding text giving context around the link, or null if unavailable.
Implementation
String? get snippet => _snippet;
Surrounding text giving context around the link, or null if unavailable.
String? get snippet => _snippet;