url/uri_pattern_utils library
URI path-template matcher with typed params — roadmap #630.
Classes
- UriPattern
-
A compiled path template such as
/users/{id}/posts/{slug}that matches concrete request paths and extracts the named segment parameters.
URI path-template matcher with typed params — roadmap #630.
/users/{id}/posts/{slug} that matches
concrete request paths and extracts the named segment parameters.