ValidationErrorUtils class final

Single validation error with optional path and code.

Constructors

ValidationErrorUtils(String message, {String? code, String? path})
Creates an error with a human-readable message, optional machine-readable code, and optional path identifying the offending field.
const

Properties

code String?
Optional machine-readable error code.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of what failed.
final
path String?
Optional path (e.g. field name) for the error.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited