AsyncBarrierUtils class final
Barrier that completes when count signals received.
Constructors
- AsyncBarrierUtils(int count)
-
Creates a barrier that completes after
countcalls to signal. Throws an ArgumentError whencountis less than 1.factory
Properties
- count → int
-
Total number of signals required for the barrier to complete.
final
-
future
→ Future<
void> -
Future that completes when the barrier has received count signals.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signal(
) → void - Decrements the remaining count; completes the barrier when count reaches zero.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited