collections/lcs_substring_utils library

Longest common substring (not subsequence) for two lists/strings (roadmap #442).

Functions

longestCommonSubstring(String a, String b) String
Returns one longest common substring of a and b (empty if none).
longestCommonSubstringLength(String a, String b) int
Returns the length of the longest common substring of a and b.