PriorityMapUtils<K extends Object, V extends Object> class
Map of priority (lower = higher priority) to queue of items.
Constructors
Properties
Methods
-
add(
K priority, V value) → void -
Enqueues
valueunderpriority, creating the queue if needed. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeFirst(
) → V? - Removes and returns the next item in priority order (front of the first queue), or null when the map is empty. Empty queues are pruned.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited