RunDetectionUtils<T extends Object> class
One run: start index, length, constant value or null for increasing.
Constructors
- RunDetectionUtils(int start, int length, T? value)
-
Creates a run beginning at
start, spanninglengthelements, with the sharedvalue(or null for a non-constant run).const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Length of the run.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
Start index in the source list.
no setter
- value → T?
-
Constant value for the run, or null for non-constant runs.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited