StreamQuantileUtils class
Approximate percentile from a stream of values (single pass, fixed memory).
Constructors
- StreamQuantileUtils(double p)
-
Creates an estimator for the quantile at
p, wherepranges from 0 to 1 (e.g. 0.5 for the median).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- p → double
-
The target quantile in the range 0 to 1.
no setter
- quantile → double
-
Current approximate quantile at p (e.g. median when p is 0.5).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
num value) → void -
Feeds
valueinto the estimator for inclusion in the quantile estimate. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited