StreamQuantileUtils class

Approximate percentile from a stream of values (single pass, fixed memory).

Constructors

StreamQuantileUtils(double p)

Properties

hashCode int
The hash code for this object.
no setterinherited
p double
no setter
quantile double
Current approximate quantile at p (e.g. median when p is 0.5).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(num value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited