WeightedIntervalUtils class
Interval with weight.
Constructors
- WeightedIntervalUtils(int start, int end, int weight)
-
Creates an interval spanning
starttoendwith the givenweight.const
Properties
- end → int
-
End of the interval.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
Start of the interval.
no setter
- weight → int
-
Weight (value) contributed when this interval is selected.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited