DateTimeBoundsExtensions extension
Start/end of day, week, month, quarter, year; quarter; next weekday; isWeekend.
- on
Properties
- endOfDay → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
End of day (23:59:59.999999). Audited: 2026-06-12 11:26 EDTno setter - endOfMonth → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
End of month (last day 23:59:59.999999). Audited: 2026-06-12 11:26 EDTno setter - endOfQuarter → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
End of quarter (last day of quarter month 23:59:59.999999). Audited: 2026-06-12 11:26 EDTno setter - endOfYear → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
End of year (Dec 31 23:59:59.999999). Audited: 2026-06-12 11:26 EDTno setter - isWeekend → bool
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
True if Saturday or Sunday. Audited: 2026-06-12 11:26 EDTno setter - quarter → int
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Quarter (1–4). Audited: 2026-06-12 11:26 EDTno setter - startOfDay → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Start of day (00:00:00.000000). Audited: 2026-06-12 11:26 EDTno setter - startOfMonth → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Start of month (first day 00:00:00). Audited: 2026-06-12 11:26 EDTno setter - startOfQuarter → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Start of quarter (first day of quarter month 00:00:00). Audited: 2026-06-12 11:26 EDTno setter - startOfYear → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Start of year (Jan 1 00:00:00). Same asDateTime.yearStartin date_time_extensions. Audited: 2026-06-12 11:26 EDTno setter - toAnnualDate → DateTime
-
Available on DateTime, provided by the DateTimeBoundsExtensions extension
The month/day of this date pinned to the sentinel year 0 — the canonical "recurring annual date" form (birthday, anniversary, holiday-without-year).no setter
Methods
-
endOfWeek(
{int firstWeekday = DateTime.monday}) → DateTime -
Available on DateTime, provided by the DateTimeBoundsExtensions extension
End of week (last day 23:59:59.999999).firstWeekday1 = Monday. -
nextWeekday(
) → DateTime -
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Next date that is a weekday (skips Saturday/Sunday). If this is already weekday, returns this date at 00:00:00. Audited: 2026-06-12 11:26 EDT -
sameTimeOn(
DateTime other) → DateTime -
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Same calendar date as the receiver with time components fromother. -
startOfWeek(
{int firstWeekday = DateTime.monday}) → DateTime -
Available on DateTime, provided by the DateTimeBoundsExtensions extension
Start of week.firstWeekday1 = Monday, 7 = Sunday (default Monday). -
toDayRange(
) → DateTimeRange< DateTime> -
Available on DateTime, provided by the DateTimeBoundsExtensions extension
The full local calendar day of this date as a DateTimeRange: startOfDay (00:00:00.000000) to endOfDay (23:59:59.999999).