isBeforeNow method
Checks if the date is in the past compared to the current date and time.
Returns true if this date is before now (defaults to current time).
Implementation
@useResult
bool isBeforeNow([DateTime? now]) => isBefore(now ?? DateTime.now());