GraphUtils class

Weighted directed edge.

Constructors

GraphUtils(int from, int to, [double weight = 1.0])
Creates a directed edge from node from to node to with optional weight (defaults to 1.0). Audited: 2026-06-12 11:26 EDT
const

Properties

from int
Source node index. Audited: 2026-06-12 11:26 EDT
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int
Target node index. Audited: 2026-06-12 11:26 EDT
no setter
weight double
Edge weight (cost). Audited: 2026-06-12 11:26 EDT
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited