GraphUtils class

Weighted directed edge.

Constructors

GraphUtils(int from, int to, [double weight = 1.0])
const

Properties

from int
Source node index.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int
Target node index.
no setter
weight double
Edge weight (cost).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited