IntNullableExtensions extension
- on
-
- int?
Methods
-
compareToIntNullable(
int? second) → int -
Available on int?, provided by the IntNullableExtensions extension
Returns a negative value if this is less thansecond, zero if they are equal, and a positive value if this is greater thansecond.