ListOfListExtension<T> extension
Properties
- totalLength → int
-
Available on List<
sum the total number of itemsList< , provided by the ListOfListExtension extensionT> >no setter - totalUniqueLength → int
-
Available on List<
Getting the length of toFlattenedListList< , provided by the ListOfListExtension extensionT> >no setter
Methods
-
clone(
) → List< List< T> > -
Available on List<
Returns a new list that is an exact duplicate of this list.List< , provided by the ListOfListExtension extensionT> > -
copy(
List< List< destination) → boolT> > -
Available on List<
Copies the elements of this list intoList< , provided by the ListOfListExtension extensionT> >destination. -
getChildListLengths(
) → List< int> ? -
Available on List<
Returns a list containing the lengths of the child lists in parentList.List< , provided by the ListOfListExtension extensionT> > -
toFlattenedList(
{bool ignoreNulls = true}) → List< T> ? -
Available on List<
Extension method that returns a flattened list of unique elements of type T.List< , provided by the ListOfListExtension extensionT> > -
toMatrixString(
{String lineBreak = '\n'}) → String? -
Available on List<
Converts a two-dimensional matrix into a string with comma-separated values and line breaks between rows.List< , provided by the ListOfListExtension extensionT> >