ListStringExtensions extension

Extensions on List

on

Methods

commonPrefix() String

Available on List<String>, provided by the ListStringExtensions extension

Returns the longest common prefix of all strings in this list.
commonSuffix() String

Available on List<String>, provided by the ListStringExtensions extension

Returns the longest common suffix of all strings in this list.