ListStringExtensions extension
Extensions on List
Methods
-
commonPrefix(
) → String -
Available on List<
Returns the longest common prefix of all strings in this list.String> , provided by the ListStringExtensions extension -
commonSuffix(
) → String -
Available on List<
Returns the longest common suffix of all strings in this list.String> , provided by the ListStringExtensions extension