Utility class for map operations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
countItems<
K, V> (Map< K, Iterable< inputMap) → intV> > -
Returns the total number of items across all iterable values in
inputMap. -
mapAddValue<
K, V> ({required Map< K, List< map, required K key, required V value}) → voidV> > -
Adds
valueto the list atkeywithinmap, creating the list if absent. -
mapContainsValue<
K, V> ({required Map< K, List< map, required K key, required V value}) → boolV> > -
Returns
trueif the list atkeywithinmapcontainsvalue. -
mapRemoveValue<
K, V> ({required Map< K, List< map, required K key, required V value}) → voidV> > -
Removes all occurrences of
valuefrom the list atkeywithinmap. -
mapToggleValue<
K, V> ({required Map< K, List< map, required K key, required V value, bool? add}) → voidV> > -
Toggles
valuein the list atkeywithinmap. -
toMapStringDynamic(
dynamic json, {bool ensureUniqueKey = false, bool throwOnDuplicate = false}) → Map< String, dynamic> ? -
Returns
jsonas aMap<String, dynamic>, ornullif conversion is not possible.