StringMapExtensions extension
Extension methods for String-keyed dynamic maps.
Methods
-
formatMap(
) → String -
Available on Map<
Returns a human-readable string representation of this map with indentation.String, dynamic> , provided by the StringMapExtensions extension -
getChildString(
String childKey) → String? -
Available on Map<
Returns the value forString, dynamic> , provided by the StringMapExtensions extensionchildKeyas aString, ornullif the key is missing or the value is not aString. -
getGrandchild(
String childKey, String grandChildKey) → dynamic -
Available on Map<
Returns the nested value atString, dynamic> , provided by the StringMapExtensions extensionchildKey→grandChildKey, ornullif either key is missing or the child is not a map. -
getGrandchildString(
String childKey, String grandChildKey) → String? -
Available on Map<
Returns the nested value atString, dynamic> , provided by the StringMapExtensions extensionchildKey→grandChildKeyas aString, ornullif either key is missing or the value is not aString. -
getGreatGrandchild(
{required String childKey, required String grandChildKey, required String greatGrandChildKey}) → dynamic -
Available on Map<
Returns the nested value atString, dynamic> , provided by the StringMapExtensions extensionchildKey→grandChildKey→greatGrandChildKey, ornullif any key is missing. -
getGreatGrandchildString(
{required String childKey, required String grandChildKey, required String greatGrandChildKey}) → String? -
Available on Map<
Returns the nested value atString, dynamic> , provided by the StringMapExtensions extensionchildKey→grandChildKey→greatGrandChildKeyas aString, ornullif any key is missing or the value is not aString. -
getValue(
String? key) → Map< String, dynamic> ? -
Available on Map<
Returns the value forString, dynamic> , provided by the StringMapExtensions extensionkeyas aMap<String, dynamic>, ornullif the key is missing or the value cannot be converted. -
removeKeys(
List< String> ? removeKeysList, {bool recurseChildValues = true}) → bool -
Available on Map<
ReturnsString, dynamic> , provided by the StringMapExtensions extensiontrueafter removing all keys inremoveKeysListfrom this map. -
toKeySorted(
) → Map< String, dynamic> -
Available on Map<
Returns a newString, dynamic> , provided by the StringMapExtensions extensionMap<String, dynamic>with keys sorted alphabetically.