isNotMapNullOrEmpty property
Returns true if this map is not null and not empty.
Implementation
@useResult
bool get isNotMapNullOrEmpty => this?.isNotEmpty ?? false;
Returns true if this map is not null and not empty.
@useResult
bool get isNotMapNullOrEmpty => this?.isNotEmpty ?? false;