object/shallow_copy_utils library

Functions

shallowCopyList<T>(List<T> source) List<T>
Shallow copy list/map. Roadmap #207. Returns a new list with the same elements as source. Elements are shared by reference (not deep-copied).
shallowCopyMap<K, V>(Map<K, V> source) Map<K, V>
Returns a new map with the same entries as source. Keys and values are shared by reference (not deep-copied).