LanguageRange class
A single weighted language range from an Accept-Language header.
Constructors
- LanguageRange(String tag, double quality)
-
Creates a range pairing a
tag(already lower-cased by the parser) with itsqualityweight in 0.0..1.0. Audited: 2026-06-12 11:26 EDTconst
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality → double
-
The quality weight in 0.0..1.0 (absent
q=defaults to 1.0).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The language tag, lower-cased (e.g.
en-us,fr, or*).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited