CronSchedule class
A parsed 5-field cron expression. Construct with CronSchedule.tryParse.
Properties
-
daysOfMonth
→ Set<
int> -
Allowed day-of-month values (1-31).
final
-
daysOfWeek
→ Set<
int> -
Allowed day-of-week values (0-6, Sunday=0).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hours
→ Set<
int> -
Allowed hour values (0-23).
final
- isDayOfMonthRestricted → bool
-
Whether the day-of-month field was something other than
*.final - isDayOfWeekRestricted → bool
-
Whether the day-of-week field was something other than
*.final -
minutes
→ Set<
int> -
Allowed minute values (0-59).
final
-
months
→ Set<
int> -
Allowed month values (1-12).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextRunAfter(
DateTime from) → DateTime? -
Returns the first matching time strictly after
from(at minute resolution), ornullif none occurs within four years. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
String expression) → CronSchedule? -
Parses
expression(5 whitespace-separated fields), or returnsnullif it is malformed or any field is out of range.