CsvDialectUtils class
Detected dialect: delimiter, hasHeader.
Constructors
- CsvDialectUtils({required String delimiter, required bool hasHeader})
-
Creates a detected dialect with the field
delimiterand whether the first row is a header (hasHeader).const
Properties
- delimiter → String
-
The detected field delimiter, e.g.
,for CSV or\tfor TSV.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasHeader → bool
-
Whether the first row was treated as a header row.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited