ParserErrorUtils class
Parser error with position and snippet.
Constructors
- ParserErrorUtils(String message, {int? line, int? column, String? snippet})
-
Creates a parser error with a human-readable
messageand optional position (line,column) and sourcesnippet.const
Properties
- column → int?
-
The 1-based column where the error occurred, or
nullif unknown.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- line → int?
-
The 1-based line where the error occurred, or
nullif unknown.no setter - message → String
-
The human-readable description of what went wrong.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snippet → String?
-
The offending source excerpt, or
nullif none was captured.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited