CdfPoint class
One step of an empirical CDF: a sample value and the cumulative
probability p = (count of samples ≤ value) / n, in [0, 1].
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- p → double
-
Fraction of all samples that are ≤ value; the last point's p is 1.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → num
-
A distinct sample value, ascending across the returned list.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override