QuantileSummaryUtils class
Pre-computed quantile summary for a list of numbers.
Constructors
-
QuantileSummaryUtils(List<
num> values) -
Builds a summary from
values, sorting a copy once for repeated queries.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → double
-
Largest value, or double.nan when there are no values.
no setter
- median → double
-
The median (50th percentile).
no setter
- min → double
-
Smallest value, or double.nan when there are no values.
no setter
- q1 → double
-
The first quartile (25th percentile).
no setter
- q3 → double
-
The third quartile (75th percentile).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
quantile(
double p) → double -
Returns the value at quantile
p(0.0–1.0). -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited