QuantileSummaryUtils class

Pre-computed quantile summary for a list of numbers.

Constructors

QuantileSummaryUtils(List<num> values)

Properties

hashCode int
The hash code for this object.
no setterinherited
max double
no setter
median double
no setter
min double
no setter
q1 double
no setter
q3 double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quantile(double p) double
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited