BetweenResult class
Represents the result of extracting content between delimiters.
Contains the content found between the delimiters and the remaining string after the delimiters are removed.
Example:
final result = 'hello (world) test'.betweenResult('(', ')');
print(result?.content); // 'world'
print(result?.remaining); // 'hello test'
- Annotations
Constructors
- BetweenResult(String content, String? remaining)
-
Creates a BetweenResult with the given
contentandremaining.const
Properties
- content → String
-
The content found between the delimiters.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- remaining → String?
-
The remaining string after removing the delimited section.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override