FuzzySearchUtils class

One candidate from fuzzy search with score and matched text.

Constructors

FuzzySearchUtils(int index, String text, double score)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
no setter
text String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited