FuzzySearchUtils constructor

const FuzzySearchUtils(
  1. int index,
  2. String text,
  3. double score
)

Creates a match at index in the original candidate list, holding the matched text and its computed relevance score.

Implementation

const FuzzySearchUtils(int index, String text, double score)
  : _index = index,
    _text = text,
    _score = score;