HumanNameParserUtils class

Parsed name parts.

Constructors

HumanNameParserUtils({String? first, String? middle, String? last, String? suffix})
const

Properties

first String?
no setter
hashCode int
The hash code for this object.
no setterinherited
last String?
no setter
middle String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited