DiffOp class
A single operation in a minimal edit script.
For line-based diff, text is one or more lines (may include newline). Adjacent equal/insert/delete ops with the same kind are merged so that text can represent a multi-line segment.
Constructors
- DiffOp(DiffOpKind kind, String text)
-
Creates an edit operation of the given
kindcarrying its segmenttext.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → DiffOpKind
-
The kind of edit (equal, insert, or delete).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The segment text for this operation.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited