QueryTerm class
Parsed query term: phrase or word, optional negated.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNegated → bool
-
True when this term must be excluded from results (entered as "-term").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The word or quoted phrase to match (without the leading "-" if negated).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited