SensitiveScrubUtils class

A scrubber rule: pattern is replaced by replacement when matched.

Constructors

SensitiveScrubUtils(RegExp pattern, String replacement)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern RegExp
final
replacement String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited