removeFirstChar method
Returns a new string with the first character removed.
Implementation
@useResult
String removeFirstChar() => (length < 1) ? '' : substringSafe(1);
Returns a new string with the first character removed.
@useResult
String removeFirstChar() => (length < 1) ? '' : substringSafe(1);