removeLastChar method
Returns a new string with the last character removed.
Implementation
@useResult
String removeLastChar() => (length < 1) ? '' : substringSafe(0, length - 1);
Returns a new string with the last character removed.
@useResult
String removeLastChar() => (length < 1) ? '' : substringSafe(0, length - 1);