isNotNullOrEmpty property
IMPORTANT: do not call ?.isNotNullOrEmpty as it will chain to null not a bool Return true if the string is not null and not empty
Implementation
@useResult
bool get isNotNullOrEmpty => this?.isNotEmpty ?? false;
IMPORTANT: do not call ?.isNotNullOrEmpty as it will chain to null not a bool Return true if the string is not null and not empty
@useResult
bool get isNotNullOrEmpty => this?.isNotEmpty ?? false;