firstWord method
Returns the first word of this string, or null if empty.
Implementation
@useResult
String? firstWord() {
if (isEmpty) {
return null;
}
return words()?.firstOrNull;
}
Returns the first word of this string, or null if empty.
@useResult
String? firstWord() {
if (isEmpty) {
return null;
}
return words()?.firstOrNull;
}