SeqDiffKind enum
The kind of change an edit-script step represents.
Values
- equal → const SeqDiffKind
-
The value is present in both inputs (unchanged).
- insert → const SeqDiffKind
-
The value is present only in the new input (added).
- delete → const SeqDiffKind
-
The value is present only in the old input (removed).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SeqDiffKind> - A constant List of the values in this enum, in order of their declaration.