ParseErr<T extends Object> class
final
Failed parse result with message and optional details.
Constructors
-
ParseErr(String message, [StackTrace? details])
-
Creates a failure with an error
message and optional details trace.
Properties
-
details
→ StackTrace?
-
Optional stack trace from the parse exception.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
message
→ String
-
Human-readable error message.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
valueOrNull
→ T?
-
The parsed value if successful, or null if failed.
no setteroverride
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override