ParseOk<T extends Object> class
final
Successful parse result holding the parsed value.
- Inheritance
-
- Object
- SafeParseUtils<
T> - ParseOk
Constructors
- ParseOk(T value)
-
Wraps a successfully parsed
value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The parsed value.
no setter
- valueOrNull → T?
-
The parsed value if successful, or null if failed.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited