ValidationErrors class final
Aggregates multiple validation errors (roadmap #684).
Constructors
-
ValidationErrors([List<
ValidationErrorUtils> ? list]) -
Creates a collector, optionally seeded with an existing
listof errors.
Properties
-
errors
→ List<
ValidationErrorUtils> -
Unmodifiable list of all errors.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
True when there are no errors.
no setter
- isNotEmpty → bool
-
True when there is at least one error.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
ValidationErrorUtils e) → void - Appends a single error.
-
addAll(
Iterable< ValidationErrorUtils> e) → void -
Appends all errors from
e. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited